def DLbN(projectname,type):
    if projectname=='RHS'and type=='*.EXE':
        print('Project name:RHS')
        print('Project update date:2025/1/12')
        print('Project creator:ANYTHING group.2025')
        print('Project License:Not OS')
        input('Press Enter to download *.EXE file')
        import webbrowser
        webbrowser.open('https://developer-oss.lanrar.com/file/?AWdVaw8+U2JVXAM7Cz5TPwM8BDwHNVMwCmRVPV0vVTEGfltpAXoENgM8U2lUZVMNVWZUNVIwAjJXYQY4XDZbYgE2VTEPY1MxVSUDMwssU28DYQQwB2lTYQo+VWRdNlVyBnZbfAFhBGIDZVM3VDVTfVU/VGBSIgIxV2cGL1w1Wz4BNlU6D2ZTNFVgA2ELPVNnA20ENwc7U2QKaFU3XWVVZgYzWzgBbQRoA2ZTPVRkU2ZVNlQ3UjoCNVcxBjhcLls/AXlVZw90U3JVcAMwCy1TOwM9BDwHbFNiCj9VZl0xVWwGMFsqASgEOQM4U2BUZlNvVT5UZlI+AjdXYAY5XDJbYgE3VToPfFMpVSUDMwszUyUDZAQxB35TJAp9VSRdPFVlBjFbPwFrBGADbFM0VDJTZFU8VHdSeAJpVyAGPVwxW2gBMVUsD2BTNFUyA3sLblNhA2wELwdqU2AKP1V9XSdVMAZpW3sBMgQPAzZTblQ9U2I=')
def DLbID(projectID,type):
    if projectID=='036-278-852'and type=='*.EXE':
        print('Project name:RHS')
        print('Project update date:2025/1/12')
        print('Project creator:ANYTHING group.2025')
        print('Project License:Not OS')
        input('Press Enter to download *.EXE file')
        import webbrowser
        webbrowser.open('https://developer-oss.lanrar.com/file/?AWdVaw8+U2JVXAM7Cz5TPwM8BDwHNVMwCmRVPV0vVTEGfltpAXoENgM8U2lUZVMNVWZUNVIwAjJXYQY4XDZbYgE2VTEPY1MxVSUDMwssU28DYQQwB2lTYQo+VWRdNlVyBnZbfAFhBGIDZVM3VDVTfVU/VGBSIgIxV2cGL1w1Wz4BNlU6D2ZTNFVgA2ELPVNnA20ENwc7U2QKaFU3XWVVZgYzWzgBbQRoA2ZTPVRkU2ZVNlQ3UjoCNVcxBjhcLls/AXlVZw90U3JVcAMwCy1TOwM9BDwHbFNiCj9VZl0xVWwGMFsqASgEOQM4U2BUZlNvVT5UZlI+AjdXYAY5XDJbYgE3VToPfFMpVSUDMwszUyUDZAQxB35TJAp9VSRdPFVlBjFbPwFrBGADbFM0VDJTZFU8VHdSeAJpVyAGPVwxW2gBMVUsD2BTNFUyA3sLblNhA2wELwdqU2AKP1V9XSdVMAZpW3sBMgQPAzZTblQ9U2I=')